
/*
 * The olsr.org Optimized Link-State Routing daemon version 2 (olsrd2)
 * Copyright (c) 2004-2015, the olsr.org team - see HISTORY file
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * * Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in
 *   the documentation and/or other materials provided with the
 *   distribution.
 * * Neither the name of olsr.org, olsrd nor the names of its
 *   contributors may be used to endorse or promote products derived
 *   from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * Visit http://www.olsr.org for more information.
 *
 * If you find this software useful feel free to make a donation
 * to the project. For more information see the website or contact
 * the copyright holders.
 *
 */

/**
 * @file
 */

#ifndef DLEP_INTERFACE_H_
#define DLEP_INTERFACE_H_

#include "common/common_types.h"
#include "common/avl.h"
#include "core/oonf_logging.h"
#include "subsystems/oonf_packet_socket.h"

/**
 * Interface that is used for one or multiple dlep sessions
 */
struct dlep_if {
  /*! pseudo session for UDP communication on interface */
  struct dlep_session session;

  /*! name of layer2 interface */
  char l2_ifname[IF_NAMESIZE];

  /*! UDP socket for discovery */
  struct oonf_packet_managed udp;

  /*! UDP socket configuration */
  struct oonf_packet_managed_config udp_config;

  /*! dynamic buffer for UDP output */
  struct autobuf udp_out;

  /*! true if radio should only accept a single session */
  bool single_session;

  /*! hook into session tree, interface name is the key */
  struct avl_node _node;

  /*! tree of all radio sessions */
  struct avl_tree session_tree;
};

int dlep_if_add(struct dlep_if *interf, const char *ifname,
    const struct oonf_layer2_origin *l2_origin,
    enum oonf_log_source log_src, bool radio);
void dlep_if_remove(struct dlep_if *interface);

#endif /* DLEP_INTERFACE_H_ */
